==> mypy_boto3_resiliencehub-1.21.23-py3-none-any.whl: mypy_boto3_resiliencehub/literals.py <==
"""
Type annotations for resiliencehub service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resiliencehub/literals.html)

Usage::

    ```python
    from mypy_boto3_resiliencehub.literals import AlarmTypeType

    data: AlarmTypeType = "Canary"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "AlarmTypeType",
    "AppComplianceStatusTypeType",
    "AppStatusTypeType",
    "AssessmentInvokerType",
    "AssessmentStatusType",
    "ComplianceStatusType",
    "ConfigRecommendationOptimizationTypeType",
    "CostFrequencyType",
    "DataLocationConstraintType",
    "DisruptionTypeType",
    "EstimatedCostTierType",
    "HaArchitectureType",
    "PhysicalIdentifierTypeType",
    "RecommendationComplianceStatusType",
    "RecommendationTemplateStatusType",
    "RenderRecommendationTypeType",
    "ResiliencyPolicyTierType",
    "ResourceImportStatusTypeType",
    "ResourceMappingTypeType",
    "ResourceResolutionStatusTypeType",
    "SopServiceTypeType",
    "TemplateFormatType",
    "TestRiskType",
    "TestTypeType",
    "ResilienceHubServiceName",
    "ServiceName",
    "ResourceServiceName",
)


AlarmTypeType = Literal["Canary", "Composite", "Event", "Logs", "Metric"]
AppComplianceStatusTypeType = Literal[
    "ChangesDetected", "NotAssessed", "PolicyBreached", "PolicyMet"
]
AppStatusTypeType = Literal["Active", "Deleting"]
AssessmentInvokerType = Literal["System", "User"]
AssessmentStatusType = Literal["Failed", "InProgress", "Pending", "Success"]
ComplianceStatusType = Literal["PolicyBreached", "PolicyMet"]
ConfigRecommendationOptimizationTypeType = Literal[
    "BestAZRecovery", "BestAttainable", "LeastChange", "LeastCost", "LeastErrors"
]
CostFrequencyType = Literal["Daily", "Hourly", "Monthly", "Yearly"]
DataLocationConstraintType = Literal["AnyLocation", "SameContinent", "SameCountry"]
DisruptionTypeType = Literal["AZ", "Hardware", "Region", "Software"]
EstimatedCostTierType = Literal["L1", "L2", "L3", "L4"]
HaArchitectureType = Literal[
    "BackupAndRestore", "MultiSite", "NoRecoveryPlan", "PilotLight", "WarmStandby"
]
PhysicalIdentifierTypeType = Literal["Arn", "Native"]
RecommendationComplianceStatusType = Literal[
    "BreachedCanMeet", "BreachedUnattainable", "MetCanImprove"
]
RecommendationTemplateStatusType = Literal["Failed", "InProgress", "Pending", "Success"]
RenderRecommendationTypeType = Literal["Alarm", "Sop", "Test"]
ResiliencyPolicyTierType = Literal[
    "CoreServices", "Critical", "Important", "MissionCritical", "NonCritical"
]
ResourceImportStatusTypeType = Literal["Failed", "InProgress", "Pending", "Success"]
ResourceMappingTypeType = Literal["AppRegistryApp", "CfnStack", "Resource", "ResourceGroup"]
ResourceResolutionStatusTypeType = Literal["Failed", "InProgress", "Pending", "Success"]
SopServiceTypeType = Literal["SSM"]
TemplateFormatType = Literal["CfnJson", "CfnYaml"]
TestRiskType = Literal["High", "Medium", "Small"]
TestTypeType = Literal["AZ", "Hardware", "Region", "Software"]
ResilienceHubServiceName = Literal["resiliencehub"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectparticipant",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "polly",
    "pricing",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]

==> mypy_boto3_resiliencehub-1.21.30-py3-none-any.whl: mypy_boto3_resiliencehub/literals.py <==
"""
Type annotations for resiliencehub service literal definitions.

[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_resiliencehub/literals/)

Usage::

    ```python
    from mypy_boto3_resiliencehub.literals import AlarmTypeType

    data: AlarmTypeType = "Canary"
    ```
"""
import sys

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal


__all__ = (
    "AlarmTypeType",
    "AppComplianceStatusTypeType",
    "AppStatusTypeType",
    "AssessmentInvokerType",
    "AssessmentStatusType",
    "ComplianceStatusType",
    "ConfigRecommendationOptimizationTypeType",
    "CostFrequencyType",
    "DataLocationConstraintType",
    "DisruptionTypeType",
    "EstimatedCostTierType",
    "HaArchitectureType",
    "PhysicalIdentifierTypeType",
    "RecommendationComplianceStatusType",
    "RecommendationTemplateStatusType",
    "RenderRecommendationTypeType",
    "ResiliencyPolicyTierType",
    "ResourceImportStatusTypeType",
    "ResourceMappingTypeType",
    "ResourceResolutionStatusTypeType",
    "SopServiceTypeType",
    "TemplateFormatType",
    "TestRiskType",
    "TestTypeType",
    "ResilienceHubServiceName",
    "ServiceName",
    "ResourceServiceName",
)


AlarmTypeType = Literal["Canary", "Composite", "Event", "Logs", "Metric"]
AppComplianceStatusTypeType = Literal[
    "ChangesDetected", "NotAssessed", "PolicyBreached", "PolicyMet"
]
AppStatusTypeType = Literal["Active", "Deleting"]
AssessmentInvokerType = Literal["System", "User"]
AssessmentStatusType = Literal["Failed", "InProgress", "Pending", "Success"]
ComplianceStatusType = Literal["PolicyBreached", "PolicyMet"]
ConfigRecommendationOptimizationTypeType = Literal[
    "BestAZRecovery", "BestAttainable", "LeastChange", "LeastCost", "LeastErrors"
]
CostFrequencyType = Literal["Daily", "Hourly", "Monthly", "Yearly"]
DataLocationConstraintType = Literal["AnyLocation", "SameContinent", "SameCountry"]
DisruptionTypeType = Literal["AZ", "Hardware", "Region", "Software"]
EstimatedCostTierType = Literal["L1", "L2", "L3", "L4"]
HaArchitectureType = Literal[
    "BackupAndRestore", "MultiSite", "NoRecoveryPlan", "PilotLight", "WarmStandby"
]
PhysicalIdentifierTypeType = Literal["Arn", "Native"]
RecommendationComplianceStatusType = Literal[
    "BreachedCanMeet", "BreachedUnattainable", "MetCanImprove"
]
RecommendationTemplateStatusType = Literal["Failed", "InProgress", "Pending", "Success"]
RenderRecommendationTypeType = Literal["Alarm", "Sop", "Test"]
ResiliencyPolicyTierType = Literal[
    "CoreServices", "Critical", "Important", "MissionCritical", "NonCritical"
]
ResourceImportStatusTypeType = Literal["Failed", "InProgress", "Pending", "Success"]
ResourceMappingTypeType = Literal["AppRegistryApp", "CfnStack", "Resource", "ResourceGroup"]
ResourceResolutionStatusTypeType = Literal["Failed", "InProgress", "Pending", "Success"]
SopServiceTypeType = Literal["SSM"]
TemplateFormatType = Literal["CfnJson", "CfnYaml"]
TestRiskType = Literal["High", "Medium", "Small"]
TestTypeType = Literal["AZ", "Hardware", "Region", "Software"]
ResilienceHubServiceName = Literal["resiliencehub"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "alexaforbusiness",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "backup",
    "backup-gateway",
    "batch",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecommit",
    "codedeploy",
    "codeguru-reviewer",
    "codeguruprofiler",
    "codepipeline",
    "codestar",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectparticipant",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "dax",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "drs",
    "ds",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "elastic-inference",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "fsx",
    "gamelift",
    "gamesparks",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "honeycode",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector2",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot1click-devices",
    "iot1click-projects",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "kafka",
    "kafkaconnect",
    "kendra",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "machinelearning",
    "macie",
    "macie2",
    "managedblockchain",
    "marketplace-catalog",
    "marketplace-entitlement",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhubstrategy",
    "mobile",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "network-firewall",
    "networkmanager",
    "nimble",
    "opensearch",
    "opsworks",
    "opsworkscm",
    "organizations",
    "outposts",
    "panorama",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "polly",
    "pricing",
    "proton",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "rekognition",
    "resiliencehub",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-runtime",
    "savingsplans",
    "schemas",
    "sdb",
    "secretsmanager",
    "securityhub",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-incidents",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "support",
    "swf",
    "synthetics",
    "textract",
    "timestream-query",
    "timestream-write",
    "transcribe",
    "transfer",
    "translate",
    "voice-id",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "worklink",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
